@@ -117,7 +117,7 @@ class KerasJsonModelImport:
         self.layer_data_adjustments(data, layer_metadata)
         node = NodeResponse(id=str(self.id), name=layer["class_name"], data=data)
         if 'wrapper' in layer:
-            node.__setattr__('wrapper', layer['wrapper'])
+            node.wrapper = layer['wrapper']
         self.nodes_cache[node_key] = node
 
     @classmethod
@@ -157,7 +157,7 @@ class KerasJsonModelImport:
             data["output_blocks"] = []
             node = NodeResponse(id=str(self.id), name=layer["class_name"], data=data)
             if 'wrapper' in layer:
-                node.__setattr__('wrapper', layer['wrapper'])
+                node.wrapper = layer['wrapper']
             self.nodes_cache[layer['name']] = node
 
             self.id += 1
@@ -176,9 +176,9 @@ class KerasJsonModelImport:
         layer_metadata = self.ui_components.get(node.name)
         if node.name == 'Representation Block' or layer_metadata is None:
             if direction == 'inputs':
-                connection_format = f"{node.id}-{'in'}-0"
+                connection_format = f"{node.id}-input"
             else:
-                connection_format = f"{node.id}-{'out'}-0"
+                connection_format = f"{node.id}-feature_map"
         elif node.name == 'Dataset':
             connection_format = f"{node.id}-{node_input_layer['name']}"
         else:
@@ -230,5 +230,7 @@ def _add_origin_name_to_nodes(nodes: Dict[str, NodeResponse]):
             node.data.pop("name")
 
 
-DATASET_DATA = {'datasetVersion': {'metadata': {'setup': {'inputs': [], 'outputs': [], 'subsets': [], 'metadata': []}}},
+DATASET_DATA = {'datasetVersion': {'metadata': {'setup': {'preprocess': {'training_length': 0, 'validation_length': 0},
+                'inputs': [], 'metadata': [], 'outputs': [], 'decoders': [], 'prediction_types': [],
+                'custom_loss_names': []}}},
                 'type': 'dataset'}
